from deep_translator import GoogleTranslator
from langdetect import detect

class AutoTranslate:
    def __init__(self, selected_lang: str = "en"):
        self.selected_lang = selected_lang.lower()
    
    def translate(self, text: str):
        try:
            detected_lang = detect(text)
            if detected_lang == self.selected_lang:
                return text  # No need to translate
            return GoogleTranslator(source='auto', target=self.selected_lang).translate(text)
        except Exception as e:
            return f"Translation error: {e}"



from setuptools import setup, find_packages
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="auto_translate",
    version="1.5",
    packages=find_packages(),
    install_requires=["deep_translator", "langdetect"],
    description="A simple automatic translation library",
    author="v4d6",
    author_email="",
    url="",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    long_description=long_description,
    long_description_content_type='text/markdown'
)
